@@ -54,9 +54,11 @@ def get_container(
         namespaces=namespaces,
         value=builder.query(
             typeName=typeName,
-            value=builder.contains(
-                geom_prop=geom_prop,
-                geom=builder.point(coordinates=point, srs=3857)
+            value=builder.filter(
+                value=builder.contains(
+                    geom_prop=geom_prop,
+                    geom=builder.point(coordinates=point, srs=3857)
+                )
             )
         )
     )
\ No newline at end of file
